// compile like this 
// rootcint -f glboxDict.cxx -c glbox.h glboxLinkDef.h
// g++ `root-config --cflags --glibs` -o glbox glbox.cxx glboxDict.cxx
//
#include <TApplication.h>
#include <TGClient.h>
#include <TCanvas.h>
#include <TPad.h>
#include <TPaveLabel.h>
#include <TH3.h>
#include <TRandom.h>
#include <TGButton.h>
#include <TRootEmbeddedCanvas.h>
#include <TStyle.h>
#include <TGLHistPainter.h>
#include "glbox.h"
#include "stdio.h"

int a=0;

MyMainFrame::MyMainFrame(const TGWindow *p,UInt_t w,UInt_t h)
	: TGMainFrame(p,w,h) {
		gStyle->SetCanvasPreferGL(true);
		fEcanvas = new TRootEmbeddedCanvas ("glc",this,850,400);
		AddFrame(fEcanvas, new TGLayoutHints(kLHintsExpandX | kLHintsExpandY, 10,10,10,1));
		TGHorizontalFrame *hframe=new TGHorizontalFrame(this, 200,40);

		TGTextButton *save = new TGTextButton(hframe,"&Save");
		save->Connect("Clicked()","MyMainFrame",this,"Save()");
		hframe->AddFrame(save, new TGLayoutHints(kLHintsCenterX,2,2,2,2));

		TGTextButton *draw = new TGTextButton(hframe,"&Draw");
		draw->Connect("Clicked()","MyMainFrame",this,"DoDraw()");
		hframe->AddFrame(draw, new TGLayoutHints(kLHintsCenterX,5,5,3,4));

		TGTextButton *exit = new TGTextButton(hframe,"&Exit ", "gApplication->Terminate()");
		hframe->AddFrame(exit, new TGLayoutHints(kLHintsCenterX,5,5,3,4));
		AddFrame(hframe,new TGLayoutHints(kLHintsCenterX,2,2,2,2));



		SetWindowName("glbox");
		MapSubwindows();
		Resize(GetDefaultSize());
		MapWindow();	
	}

void MyMainFrame::DoDraw() {
	TCanvas *fCanvas = fEcanvas->GetCanvas();
	fCanvas->cd();

	TPaveLabel *title = new TPaveLabel(0.04, 0.86, 0.96, 0.98, "\"glbox\" and \"glbox1\" options for TH3.");
	title->SetFillColor(32);
	title->Draw();

	TPad *boxPad  = new TPad("box", "box", 0.02, 0.02, 0.48, 0.82);
	TPad *box1Pad = new TPad("box1", "box1", 0.52, 0.02, 0.98, 0.82);
	boxPad->Draw();
	box1Pad->Draw();

	TH3F *h31 = new TH3F("h31", "h31", 10, -1, 1, 10, -1, 1, 10, -1, 1);
	h31->FillRandom("gaus");
	h31->SetFillColor(2);
	boxPad->cd();
	//  h31->Draw("box");
	h31->Draw("glbox");

	TH3F *h32 = new TH3F("h32", "h32", 10, -2, 2, 10, -1, 1, 10, -3, 3);
	h32->FillRandom("gaus");
	h32->SetFillColor(4);
	box1Pad->cd();
	//  h32->Draw("iso");
	h32->Draw("glbox1");

	fCanvas->Update();
	fCanvas->SaveAs("abc.png");
}

MyMainFrame::~MyMainFrame() {
	Cleanup();
}

void MyMainFrame::Save(){
	char f[100];
	sprintf(f,"image%i.png",a++);
	printf ("Savind as %s \n",f);
	TCanvas *fCanvas = fEcanvas->GetCanvas();
	fCanvas->Update();
	fCanvas->SaveAs(f);

}

int main(int argc, char **argv) {
	TApplication theApp("App",&argc,argv);
	new MyMainFrame(gClient->GetRoot(),600,400);
	theApp.Run();
	return 0;
}
